@@ -232,7 +232,9 @@ def DrawGraph(self, QtGui):
         #clear whole pitmap (remove old data)
         paint.setPen(QtGui.QColor(data.GraphBackground))
         paint.setBrush(QtGui.QColor(data.GraphBackground))
-        paint.drawRect(0,0,records.MaxArrayDataLen+10,data.GraphBitMapHeight)
+#        paint.drawRect(0,0,records.MaxArrayDataLen+10,data.GraphBitMapHeight)
+        paint.drawRect(0,0, data.GraphBitMapLen, data.Ysize)         
+            
 
         #Draw sleep phase background
         paint.setPen(QtGui.QColor(data.GraphBackground2))
@@ -377,7 +379,9 @@ def DrawGraph(self, QtGui):
             x1=min(Tuple2Index(t), Tuple2Index(end))-data.Derivation*Xscale
             x01=(x1-GraphStart_index)/Xscale
             y=20
-            paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
+#            print "Lucid dream"
+            points = [QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y)]
+            paint.drawPolygon(points)
             paint.drawRect(x00, y-1, x01-x00, 2)
 
        #WakeUp option
@@ -390,7 +394,9 @@ def DrawGraph(self, QtGui):
             x1=min(Tuple2Index(t), Tuple2Index(records.AlarmTimeWindowEnd_tuple))-data.Derivation*Xscale
             x01=(x1-GraphStart_index)/Xscale
             y=20
-            paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
+#            print "wake up"
+            points=[QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y)]
+            paint.drawPolygon(points)
             paint.drawRect(x00, y-1, x01-x00, 2)
 #            paint.drawPolygon(QPointF(x00, y-5), QPointF(x01, y-5), QPointF(x01, y-8))
 
@@ -455,12 +461,7 @@ def DrawGraph(self, QtGui):
 ##        paint.setPen(QtGui.QColor("gray"))
 ##        paint.drawText(data.GraphBitMapLen-70, data.Ysize+12, str(data.Yscale_Movement)+", "+str(data.Yscale_Sleep_Pattern)+", "+str(data.Yoffset_Sleep_Pattern)) #settings (for debbigging)
 
-        #Draw border around graph
-        paint.setPen(QtGui.QColor("white"))
-        paint.drawLine(0, 0, 0, data.Ysize)  #left side
-        paint.drawLine(data.GraphBitMapLen-1, 0, data.GraphBitMapLen-1, data.Ysize)  #right side
-        paint.drawLine(0, 0, data.GraphBitMapLen-1, 0)  #top
-        paint.drawLine(0, data.Ysize, data.GraphBitMapLen-1, data.Ysize)  #bottom
+        
 
         #When in test mode, make noise if last moveent is over trigger level
         if(data.QuickMode==True): MakeNoise_if_over_trigger(records.arrData[6][records.Index-data.Derivation-1])
@@ -468,6 +469,16 @@ def DrawGraph(self, QtGui):
     except:
         print "Error while drawing the graph"
         print sys.exc_info()
+        
+    try:
+        #Draw border around graph
+        paint.setPen(QtGui.QColor("white"))
+        paint.drawLine(0, 0, 0, data.Ysize)  #left side
+        paint.drawLine(data.GraphBitMapLen-1, 0, data.GraphBitMapLen-1, data.Ysize)  #right side
+        paint.drawLine(0, 0, data.GraphBitMapLen-1, 0)  #top
+        paint.drawLine(0, data.Ysize, data.GraphBitMapLen-1, data.Ysize)  #bottom
+    except:
+        pass
 
     paint.end()
 
@@ -512,7 +523,8 @@ def DrawStatistic(self, QtGui, QtCore):
     #clear whole pitmap (remove old data)
     paint.setPen(QtGui.QColor(data.GraphBackground))
     paint.setBrush(QtGui.QColor(data.GraphBackground))
-    paint.drawRect(0, 0, data.StatisticsBitMapLen, data.StatisticsBitMapHeight)
+#    paint.drawRect(0, 0, data.StatisticsBitMapLen, data.StatisticsBitMapHeight)
+
 
     paint.setPen(QtGui.QColor(data.GraphBackground))
 
@@ -557,12 +569,6 @@ def DrawStatistic(self, QtGui, QtCore):
         paint.setPen(QtGui.QColor(data.Deep_Sleep_Color))
         paint.drawRect(120, y, records.arrStatData[2][3], 10)
 
-
-
-
-
-
-
     paint.end()
 
 
@@ -683,14 +689,22 @@ def PrintRecordData(ShowArray=True):
 
     print "Use_Lucid_Dream_Song:", records.Use_Lucid_Dream_Song
     print "Lucid_Dream_Song_Start_tuple:", records.Lucid_Dream_Song_Start_tuple
-    print "Lucid_Dream_Song:", records.Lucid_Dream_Song
+    try:
+        f=records.Lucid_Dream_Song.encode( "utf-8" )
+    except:
+        f=records.Lucid_Dream_Song
+    print "Lucid_Dream_Song:", f
     print "Lucid_Dream_Song_Delay:", records.Lucid_Dream_Song_Delay
     print "Lucid_Dream_Song_Duration:", records.Lucid_Dream_Song_Duration
     print "Lucid_Dream_Song_Volume:", records.Lucid_Dream_Song_Volume
 
     print "Use_WakeUp_Song:", records.Use_WakeUp_Song
     print "WakeUp_Song_Start_tuple:", records.WakeUp_Song_Start_tuple
-    print "WakeUp_Song:", records.WakeUp_Song
+    try:
+        f=records.WakeUp_Song.encode( "utf-8" )
+    except:
+        f=records.WakeUp_Song
+    print "WakeUp_Song:", f
     print "WakeUp_Song_Duration:", records.WakeUp_Song_Duration
     print "WakeUp_Song_Volume:", records.WakeUp_Song_Volume
 
