@@ -38,13 +38,22 @@ DEFAULT_LANGUAGES = os.environ.get('LANG', '').split(':')
 DEFAULT_LANGUAGES += ['en_US']
 if(data.debug==True): print "Languages:", DEFAULT_LANGUAGES
 
+#default values
+lc=data.lc
+encoding=data.encoding
+
 # Try to get the languages from the default locale
 if(data.language==""):
     try:
         lc, encoding = locale.getdefaultlocale()
     except:
-        lc="en_US"
-        encoding="UTF8"
+        pass
+#        lc=data.lc
+#        encoding=data.encoding
+        
+    if(lc==None): lc=data.lc
+    if(encoding==None): encoding=data.encoding
+    
     print "Locale:", lc, ", Encoding:", encoding
     if lc:
         languages = [lc]
@@ -56,6 +65,11 @@ else:
     languages=[data.language]
     print "Locale:", data.language
 
+
+data.encoding = encoding
+data.lc = lc
+
+
 # Concat all languages (env + default locale),
 #  and here we have the languages and location of the translations
 languages += DEFAULT_LANGUAGES
