@@ -13,11 +13,17 @@ import traceback
 #import osso
 import string
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+
 
 import data
 
+if(data.UsePySide == True):
+    from PySide.QtCore import *
+    from PySide.QtGui import *
+else:    
+    from PyQt4.QtCore import *
+    from PyQt4.QtGui import *
+
 from functions_record import *
 from functions_alarm import *
 
